bayespy.inference.vmp.nodes.gaussian.GaussianToGaussianGamma.broadcasting_multiplier
====================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianToGaussianGamma.broadcasting_multiplier